@@ -1,8 +1,16 @@
+# -*- coding: utf-8 -*-
+
+# Overwrite-able vars
+overwrite_app_id = "8c6cc7b45d2568fb668be6e05b6e5a3b"
+overwrite_gcc = "KR"
+overwrite_locale = "ko_KR"
+
+
 # VLive React App ID
-AppId = {"appId": "8c6cc7b45d2568fb668be6e05b6e5a3b"}
+AppId = {"appId": overwrite_app_id}
 
 # locale parameter(url postfix)
-LocaleParam = {"gcc": "KR", "locale": "ko_KR"}
+LocaleParam = {"gcc": overwrite_gcc, "locale": overwrite_locale}
 
 PlatformPCParam = {"platformType": "PC"}
 
@@ -31,6 +39,9 @@ def referer_video(videoSeq):
 def referer_vlive():
     return {"referer": "https://www.vlive.tv/"}
 
+def referer_channel(channel_code):
+    return {"referer": "https://www.vlive.tv/channel/%s" % channel_code}
+
 
 # Endpoint
 def endpoint_post(post):
@@ -165,7 +176,8 @@ def endpoint_vod_play_info(vodId, inkey):
         "doct": "json",
         "cpt": "vtt",
         "cpl": "ko_KR",
-        "lc": "ko_KR"
+        "lc": "ko_KR",
+        "CC": "KR"
     }
     headers = {
         **HeaderCommon,
@@ -175,27 +187,14 @@ def endpoint_vod_play_info(vodId, inkey):
     return {"url": url, "params": params, "headers": headers}
 
 
-def endpoint_post_comments(post, after=None):
-    url = "https://www.vlive.tv/globalv-web/vam-web/comment/v1.0/post-%s/comments" % post
-    params = {
-        **AppId,
-        **LocaleParam,
-        "fields": "root,parent,commentId,body,emotionCount,commentCount,viewerEmotionId,viewerAvailableActions,"
-                  "createdAt,writtenIn,sticker,author,latestComments,isRestricted,lastModifierMember",
-        "startFrom": "first"
-    }
-    if after:
-        params.update({"after": after})
-    headers = {
-        **HeaderCommon,
-        **referer_post(post)
-    }
+def endpoint_post_comment_template(prefix, srl, postfix=None, after=None, field: list = None):
+    if field is None:
+        field = []
 
-    return {"url": url, "params": params, "headers": headers}
+    url = "https://www.vlive.tv/globalv-web/vam-web/comment/v1.0/%s-%s" % (prefix, srl)
+    if postfix:
+        url += "/%s" % postfix
 
-
-def endpoint_post_star_comments(post, after=None):
-    url = "https://www.vlive.tv/globalv-web/vam-web/comment/v1.0/post-%s/starComments" % post
     params = {
         **AppId,
         **LocaleParam,
@@ -205,9 +204,120 @@ def endpoint_post_star_comments(post, after=None):
     }
     if after:
         params.update({"after": after})
+
+    for item in field:
+        params["fields"] += ",%s" % item
+
     headers = {
         **HeaderCommon,
-        **referer_post(post)
+        **referer_post(srl)
     }
 
     return {"url": url, "params": params, "headers": headers}
+
+
+def endpoint_post_comments(post, after=None):
+    return endpoint_post_comment_template(
+        "post", post, postfix="comments", after=after, field=["latestComments"]
+    )
+
+
+def endpoint_post_star_comments(post, after=None):
+    return endpoint_post_comment_template(
+        "post", post, postfix="starComments", after=after
+    )
+
+
+def endpoint_comment_data(post):
+    return endpoint_post_comment_template(
+        "comment", post
+    )
+
+
+def endpoint_comment_nested(post, after=None):
+    return endpoint_post_comment_template(
+        "comment", post, postfix="comments", after=after
+    )
+
+
+def endpoint_schedule_data(schedule):
+    url = "https://www.vlive.tv/globalv-web/vam-web/schedule/v1.0/schedule-%s" % schedule
+    params = {
+        **AppId,
+        **LocaleParam,
+        "fields": "scheduleId,title,description,alarm,location,postId,videoSeq,officialVideo,photos,author,"
+                  "timezoneId,type,startAt,commentCount,emotionCount,commentWritable,availableActions,writtenIn,"
+                  "url,viewerEmotionId,channel{channelCode,channelName},post{url},timeUsing,lastModifierMember"
+    }
+    headers = {
+        **HeaderCommon,
+        "referer": "https://www.vlive.tv/schedule/%s" % schedule
+    }
+
+    return {"url": url, "params": params, "headers": headers}
+
+
+def endpoint_decode_channel_code(channel_code):
+    url = "http://api.vfan.vlive.tv/vproxy/channelplus/decodeChannelCode"
+    params = {
+        "app_id": overwrite_app_id,
+        "channelCode": channel_code,
+        "_": "1614426919000"
+    }
+    headers = {
+        **HeaderCommon,
+        **referer_vlive()
+    }
+
+    return {"url": url, "params": params, "headers": headers}
+
+
+def endpoint_channel_webpage(channel_code):
+    url = "https://www.vlive.tv/channel/%s" % channel_code
+    headers = {
+        **HeaderCommon
+    }
+
+    return {"url": url, "headers": headers}
+
+
+def endpoint_channel_grouped_boards(channel_code):
+    url = "https://www.vlive.tv/globalv-web/vam-web/board/v1.0/channel-%s/groupedBoards" % channel_code
+    params = {
+        **AppId,
+        **LocaleParam,
+        "fields": "boardId,title,boardType,openType,allowedViewers,includedCountries,excludedCountries,"
+                  "useStarFilter,payRequired,expose,channelCode,lastUpdatedAt",
+        "filter": ""
+    }
+    headers = {
+        **HeaderCommon,
+        **referer_channel(channel_code)
+    }
+
+    return {"url": url, "headers": headers, "params": params}
+
+
+def endpoint_board_posts(board, channel_code, after=None, latest=False):
+    url = "https://www.vlive.tv/globalv-web/vam-web/post/v1.0/board-%s/posts" % board
+    params = {
+        **AppId,
+        **LocaleParam,
+        "fields": "postId,officialVideo",
+        "limit": 20,
+    }
+    headers = {
+        **HeaderCommon,
+        **referer_channel(channel_code)
+    }
+    headers['referer'] += "/board/%s" % board
+
+    if after:
+        params.update({"after": after})
+
+    if latest:
+        params.update({'sortType': "LATEST"})
+    else:
+        params.update({'sortType': "OLDEST"})
+
+    return {"url": url, "headers": headers, "params": params}
